/v1/projects/{project_id}/virtualbox/vms — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »

# /v1/projects/{project_id}/virtualbox/vms

Contents

- /v1/projects/{project_id}/virtualbox/vms
  - POST /v1/projects/{project_id}/virtualbox/vms
    - Parameters
    - Response status codes
    - Input
    - Output
    - Sample session

## POST /v1/projects/{project_id}/virtualbox/vms

Create a new VirtualBox VM instance

### Parameters

- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
linked_clone | ✔ | boolean | either the VM is a linked clone or not
name | ✔ | string | VirtualBox VM instance name
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vm_id |  |  | VirtualBox VM instance identifier
vmname | ✔ | string | VirtualBox VM name (in VirtualBox itself)

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vm_id | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Sample session

    curl -i -X POST 'http://localhost:8000/projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms' -d '{"linked_clone": false, "name": "VM1", "vmname": "VM1"}'

    POST /projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms HTTP/1.1
    {
        "linked_clone": false,
        "name": "VM1",
        "vmname": "VM1"
    }

    HTTP/1.1 201
    CONNECTION: keep-alive
    CONTENT-LENGTH: 341
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/virtualbox/vms

    {
        "adapter_type": "Intel PRO/1000 MT Desktop (82540EM)",
        "adapters": 0,
        "console": 2000,
        "enable_remote_console": false,
        "headless": false,
        "name": "VM1",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "use_any_adapter": false,
        "vm_id": "1404a6c5-c0f5-4bc6-bb94-477d7e631781",
        "vmname": "VM1"
    }

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »